@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -139,7 +139,7 @@ sub gen_doc_section_links {
             my $link = ref($link0) ? $link0 : {url=>$link0};
             my $url = $link->{url};
             next if $seen_urls{$url}++;
-            $url =~ s!\A(pm|prog):(//?)?!!;
+            $url =~ s!\A(pm|pod|prog):(//?)?!!;
             $self->add_doc_lines(
                 "L<$url>." .
                     ($link->{summary} ? " $link->{summary}." : "") .
@@ -164,7 +164,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-09-26.
+This document describes version 0.80 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-09-27.
 
 =head1 SYNOPSIS
 
@@ -188,7 +188,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
